# ListFilesResponse

Response object for file list
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**files** | [**list[FileSummary]**](FileSummary.md) | List of files | [optional] 
**limit** | **int** | Limit of files in response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


